It is the package used for educational purpose only

It has a class which includes the following things:
    
class BasicMaths
    methods add(a, b), subtract(a, b), multiply(a, b), divide(a, b), remainder(a, b)
    